Email Followers
===============

A [flux](https://facebook.github.io/flux/docs/overview.html#content) approach for managing a site's email followers in Calypso.

####Public Methods

**EmailFollowersStore.getFollowers( fetchOptions );**

Returns an array of all followers that have been fetched for the given fetch options

---

**EmailFollowersStore.getPaginationData( fetchOptions );**

This data will help with pagination and infinite scroll.

###Actions
Actions get triggered by views and stores.

####Public methods.

**EmailFollowersActions.fetchFollowers( fetchOptions );**

Fetches followers in batches of 100 starting from the given page, which defaults to 1.

###Example Component Code

```
/**
 * External dependencies
 */
var React = require( 'react' );

/**
 * Internal dependencies
 */
var EmailFollowersStore = require( 'lib/followers/wpcom-followers-store' ),
	EmailFollowersActions = require( 'lib/followers/actions' );

module.exports = React.createClass( {

	displayName: 'yourComponent',

	fetchOptions: {
	    siteId: this.props.siteId,
	    type: 'email'
	},

	componentDidMount: function() {
		EmailFollowersActions.fetchFollowers( this.fetchOptions );
		EmailFollowersStore.on( 'change', this.refreshFollowers );
	},

	componentWillUnmount: function() {
		EmailFollowersStore.removeListener( 'change', this.refreshFollowers );
	},

	getInitialState: function() {
		return this.getFollowers();
	},

	getFollowers: function() {
		return {
			followers: EmailFollowersStore.getFollowers( this.props.fetchOptions )
		};
	},

	refreshFollowers: function() {
		this.setState( this.getFollowers() );
	},

	render: function() {

	}

} );

```

###Testing

To run tests go to
```cd client/lib/email-followers/ && make test```
